@@ -7,6 +7,8 @@ from .commands.postman import postman_group
 from .commands.envs import envs_group
 from .commands import config as config_
 from .commands import ci
+from .commands import asana
+from .commands import health
 
 
 def get_cli():
@@ -15,6 +17,8 @@ def get_cli():
     cli.add_command(envs_group)
     cli.add_command(config_.group)
     cli.add_command(ci.command)
+    cli.add_command(asana.group)
+    cli.add_command(health.health_group)
     return cli
 
 
