@@ -2,7 +2,6 @@ from typing import Optional
 import rich
 import subprocess
 import click
-import click
 from staircase.config import UserConfig
 from staircase.lib.click import async_cmd
 
@@ -22,10 +21,11 @@ from staircase.staircase import Staircase
 from staircase.lib.sdk.ci import clone, build, deploy
 from staircase.user_prompts import select_product_git_repo
 
-DEFAULT_CI_ENV = 'marketplace.staircaseapi.com'
+DEFAULT_CI_ENV = "marketplace.staircaseapi.com"
+
 
 @click.command(
-    "ci", 
+    "ci",
 )
 @click.argument("actions", type=click.Choice(["clone", "build", "deploy"]), nargs=-1)
 @click.option(
@@ -39,15 +39,31 @@ DEFAULT_CI_ENV = 'marketplace.staircaseapi.com'
     help="Product name in marketplace. If you dont specify clone, it will be used to get start bundle",
 )
 @click.option("--repo", "-r", help="Git repo name in Staircase")
-@click.option("--ci-env", "-ci", help="Environment where ci products will be called. Ex. mydomain.staircaseapi.com")
+@click.option(
+    "--type",
+    help="Type of bundle can be either service, data, chat or frontend",
+    default="service",
+    type=click.Choice(["service", "data", "frontend", "chat"]),
+)
+@click.option(
+    "--ci-env",
+    "-ci",
+    help="Environment where ci products will be called. Ex. mydomain.staircaseapi.com",
+)
 @click.option("--branch", "-b", help="Branch name of git clone")
-@click.option("--data", "-d", help="If this is data product", is_flag=True)
 @click.option("--verbose", "-v", help="Verbose output", is_flag=True)
 @click.option(
     "--target",
     "-t",
     help="Target domain of environment to be deployed. Ex. mydomain.staircaseapi.com",
 )
+@click.option(
+    "--arch",
+    help="Arch param of build product",
+    default="X86_64",
+    type=click.Choice(["X86_64", "ARM64"]),
+)
+@click.option("--build_env", "-be", help="Build env vars", multiple=True)
 @env_manager_provider()
 @staircase_provider()
 @user_config_provider()
@@ -58,10 +74,12 @@ async def command(
     actions,
     bundle_url,
     target,
+    type,
     product,
     branch,
     repo,
-    data: bool,
+    build_env,
+    arch,
     ci_env: str,
     verbose: bool,
     staircase: Staircase,
@@ -80,7 +98,9 @@ async def command(
     if not ci_env:
         envs = env_storage.get_all_envs()
         env_names = [env.domain_name for env in envs]
-        selected_env = prompt(env_names, header="Select ci-env, default = marketplace.staircaseapi.com...")
+        selected_env = prompt(
+            env_names, header="Select ci-env, default = marketplace.staircaseapi.com..."
+        )
         if selected_env:
             ci_env = selected_env[0]
         else:
@@ -89,7 +109,6 @@ async def command(
     ci_env: Optional[StaircaseEnvironment] = env_manager.get_staircase_env(ci_env)
     if not ci_env:
         raise click.ClickException("CI env is not saved to your envs.")
-    
 
     # Getting args
     if not user_config.github_token:
@@ -97,7 +116,10 @@ async def command(
 
     if "clone" in actions:
         if not repo:
-            repo = await select_product_git_repo(staircase=staircase, prompt_header="Select product repo to clone from...")
+            repo = await select_product_git_repo(
+                staircase=staircase,
+                prompt_header="Select product repo to clone from...",
+            )
             if not repo:
                 raise click.ClickException("You did not specify any repo")
 
@@ -110,7 +132,7 @@ async def command(
                     f"git@github.com:StaircaseAPI/{repo}.git",
                 ],
                 stdout=subprocess.PIPE,
-                text=True
+                text=True,
             )
             branches = []
             for line in pipe.stdout.splitlines():
@@ -145,7 +167,8 @@ async def command(
         and not ["build", "assess", "test", "clone"]
     ):
         product_names = [
-            product["name"] for product in await staircase.get_all_product_components()
+            product["product_name"]
+            for product in await staircase.get_all_product_components()
         ]
         products = prompt(product_names)
         if not products:
@@ -168,7 +191,11 @@ async def command(
             rich.print(f"Branch: {branch}")
             rich.print(f"Cloning...")
         bundle_url = await clone(
-            ci_env, repo=repo, branch=branch, github_token=user_config.github_token
+            ci_env,
+            repo=repo,
+            branch=branch,
+            github_token=user_config.github_token,
+            verbose=verbose,
         )
         if verbose:
             rich.print(f"[green]Cloned.")
@@ -177,7 +204,21 @@ async def command(
     if "build" in actions:
         if verbose:
             rich.print(f"Building...")
-        bundle_url = await build(ci_env=ci_env, url=bundle_url)
+
+        env_variables = {}
+
+        for env_var in build_env:
+            key, value = env_var.split("=")
+            env_variables[key] = value
+
+        bundle_url = await build(
+            ci_env=ci_env,
+            bundle_url=bundle_url,
+            type=type,
+            env_variables=env_variables,
+            verbose=verbose,
+            architecture=arch,
+        )
         if verbose:
             rich.print(f"[green]Built.")
             rich.print(bundle_url)
@@ -192,8 +233,10 @@ async def command(
         to_env = env_manager.get_staircase_env(target)
         if not to_env:
             raise click.ClickException("You have no such api in your envs saved.")
-        env_token = await staircase.get_env_token(to_env.api_key)
+        env_token = await staircase.get_env_token(to_env)
 
-        await deploy(ci_env=ci_env, url=bundle_url, env_token=env_token)
+        await deploy(
+            ci_env=ci_env, url=bundle_url, env_token=env_token, verbose=verbose
+        )
         if verbose:
             rich.print(f"[green]Deployed.")
