@@ -1,5 +1,4 @@
 import rich
-import click
 import os
 import json
 from pydantic import BaseModel
@@ -17,11 +16,17 @@ class UserConfig(BaseModel):
     postman_api_key: Optional[str]
     marketplace_api_key: Optional[str]
     github_token: Optional[str]
+    asana_token: Optional[str]
 
 
 def get_user_cfg() -> UserConfig:
     if not os.path.exists(CONFIG_FILE_PATH):
-        return UserConfig()
+        return UserConfig(
+            postman_api_key=None,
+            marketplace_api_key=None,
+            github_token=None,
+            asana_token=None
+        )
     
     with open(CONFIG_FILE_PATH, "r") as f:
         try:
@@ -30,9 +35,14 @@ def get_user_cfg() -> UserConfig:
             return user_config
         except json.JSONDecodeError:
             rich.print("[red]Config is not valid, taking default values.")
-            return UserConfig()
+            return UserConfig(
+                postman_api_key=None,
+                marketplace_api_key=None,
+                github_token=None,
+                asana_token=None
+            )
 
 
 def write_user_cfg(user_cfg: UserConfig):
     with open(CONFIG_FILE_PATH, "w+") as f:
-        json.dump(user_cfg.dict(), f)
\ No newline at end of file
+        json.dump(user_cfg.dict(), f)
