@@ -1,15 +1,13 @@
 from typing import Optional
+
 from .env_storage import EnvironmentStorage
 from .lib.sdk import StaircaseEnvironment
-from .config import Config
 
 
 class EnvironmentManager:
-    config: Config
 
-    def __init__(self, config: Config):
-        self.config = config
-        self.env_storage = EnvironmentStorage(config)
+    def __init__(self):
+        self.env_storage = EnvironmentStorage()
 
     def get_staircase_env(self, domain: str) -> Optional[StaircaseEnvironment]:
         envs = self.env_storage.get_all_envs()
