@@ -13,6 +13,16 @@ def prompt(choices=None, header="", multi=False):
     fzf = FzfPrompt()
     return fzf.prompt(choices, fzf_options=fzf_options)
 
+def prompt_numbered(choices,  *args, transform=None, **kwargs):
+    enumerated_choices = []
+    for idx, choice in enumerate(choices):
+        if transform:
+            choice = transform(choice)
+        enumerated_choices.append(f"{idx}:{choice}")
+
+    selected = prompt(enumerated_choices)[0]
+    idx, _ = selected.split(":")
+    return  choices[int(idx)]
 
 
 
