@@ -6,7 +6,7 @@ from .staircase import Staircase
 async def select_product_git_repo(staircase: Staircase, prompt_header: str) -> Optional[str]:
     products = await staircase.get_all_product_components()
 
-    product_names = list(map(lambda e: e["name"], products))
+    product_names = list(map(lambda e: e["product_name"], products))
     product_names_selected = prompt(product_names, header=prompt_header)
     if not product_names_selected:
         return None
